@@ -193,6 +193,7 @@ class Users(_defaults_.Defaults):
 		#
 	def update(self,
 		# required:
+		username=None,
 		email=None,
 		# optionals:
 		name=None,
@@ -204,6 +205,13 @@ class Users(_defaults_.Defaults):
 		#email_verified=None,
 	):
 
+		# checks.
+		username, email = self.__correct_username_email__(username, email)
+
+		# check parameters.
+		if [username,email] == [None,None]:
+			return dev0s.response.error(self.__traceback__(function="update")+" Define one of the following parameters [email, username].")
+
 		# load.
 		response = self.get(email=email)
 		if response.error != None: return response
@@ -229,7 +237,6 @@ class Users(_defaults_.Defaults):
 			name=name,
 			superuser=superuser,)
 		if not response.success: return response
-		user = response.user
 
 		# update firestore.
 		response = self.load_data(email=email, username=username)
@@ -247,7 +254,7 @@ class Users(_defaults_.Defaults):
 
 		# save pass.
 		if password != None:
-			response = self.save_password(email=user.email, username=username, password=password)
+			response = self.save_password(email=email, username=username, password=password)
 			if not response.success: return response
 
 		# handle success.
@@ -809,21 +816,17 @@ class Users(_defaults_.Defaults):
 			customer_id = response.id
 
 		# map user's stripe subscriptions.
-		plan_ids, sub_ids, active_product_subs = [], {}, {}
 		response = self.stripe.subscriptions.get(email=email)
-		if not response.success and "No subscriptions found for user" not in response.error: return response
-		elif not response.success and "No subscriptions found for user" in response.error:
-			plan_ids, sub_ids, active_product_subs = [], {}, {}
-		else:
-			plan_ids, sub_ids, active_product_subs = [], {}, {}
-			for _plan_id_,info in response.subscriptions.items():
-				response = self.stripe.get_product_id_by_plan_id(_plan_id_)
-				if not response.success: return response
-				_product_id_ = response.id
-				if _product_id_ == product_id:
-					active_product_subs[info["plan_id"]] = info["subscription_id"]	
-				plan_ids.append(info["plan_id"])
-				sub_ids[info["plan_id"]] = info["subscription_id"]
+		if not response.success: return response
+		plan_ids, sub_ids, active_product_subs = [], {}, {}
+		for _plan_id_,info in response.subscriptions.items():
+			response = self.stripe.get_product_id_by_plan_id(_plan_id_)
+			if not response.success: return response
+			_product_id_ = response.id
+			if _product_id_ == product_id:
+				active_product_subs[info["plan_id"]] = info["subscription_id"]	
+			plan_ids.append(info["plan_id"])
+			sub_ids[info["plan_id"]] = info["subscription_id"]
 
 		# check already subscribed.
 		if plan_id in plan_ids:
